@@ -76,7 +76,7 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 	{
 		// get the application's name and let derived classes
 		// handle it
-		m_app_name = path(argv[0]).stem();
+		m_app_name = path(argv[0]).stem().string();
 		HandleApplicationName();
 
 		// evaluate command line
@@ -114,15 +114,15 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 			// .pdrxrc in current directory?
 			path p(".");
 			p /= ".pdrxrc";
-			if (ifstream(p.file_string().c_str()).good())
-				m_config_file = p.file_string();
+			if (ifstream(p.string().c_str()).good())
+				m_config_file = p.string();
 			else
 			{
 				// .pdrxrc in ~?
 				p = GetStringOption("home");
 				p /= ".pdrxrc";
-				if (ifstream(p.file_string().c_str()).good())
-					m_config_file = p.file_string();
+				if (ifstream(p.string().c_str()).good())
+					m_config_file = p.string();
 				else
 				{
 					// pdrxrc in ~/.config/pdrx?
@@ -130,8 +130,8 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 					p /= ".config";
 					p /= "pdrx";
 					p /= "pdrxrc";
-					if (ifstream(p.file_string().c_str()).good())
-						m_config_file = p.file_string();
+					if (ifstream(p.string().c_str()).good())
+						m_config_file = p.string();
 				}
 			}
 		}
@@ -264,6 +264,28 @@ bool Config::HasOption (const string& option) const
 	return false;
 }
 
+bool Config::HasAnyOption (const vector<string>& except) const
+{
+	try
+	{
+		const std::vector<shared_ptr<option_description> >& options = m_od_visible.options();
+		foreach(shared_ptr<option_description> od, options)
+		{
+			const string& option = od->long_name();
+			if (find(except.begin(), except.end(), option) == except.end())
+			{
+				if (HasOption(option))
+					return true;
+			}
+		}
+	}
+	catch (...)
+	{
+	}
+
+	return false;
+}
+
 bool Config::GetBoolOption (const string& option) const
 {
 	try
@@ -351,7 +373,7 @@ string Config::GetFilenameOption (const string& option) const
 				filename.erase(0, 2);
 				path p(any_cast<string>(m_vm["home"].value()));
 				p /= filename;
-				filename = p.file_string();
+				filename = p.string();
 			}
 			return filename;
 		}
@@ -419,7 +441,7 @@ Poco::TextEncoding& SpecificEncoding (const string& encoding) throw (Xception)
 	if (p)
 		return *p;
 	else
-		THROW(format("unknown encoding: ") % encoding);
+		THROW(format("unknown encoding: %s") % encoding);
 }
 
 string Decode (const string& text, Poco::TextEncoding& from)
