@@ -118,6 +118,22 @@ void MySQLDatabase::NoUnitColumnCallback () throw (Xception)
 	CATCH_RETHROW("could not update schema")
 }
 
+void MySQLDatabase::NoLastRssUpdatesCallback () throw (Xception)
+{
+	if (m_verbose)
+		encoded::cout << "updating schema" << endl;
+
+	try
+	{
+		(*m_pSession) << "create table TLastRssUpdates "
+				 "("
+					"f varchar(100) not null primary key,"
+					"t char(19) not null"
+				 ") engine=InnoDB;", now;
+	}
+	CATCH_RETHROW("could not update schema")
+}
+
 void MySQLDatabase::CreateCollectionInSchema (const string& name, char type, const string& tblname, const string& purpose, const string& unit) throw (Xception)
 {
 	try
