@@ -31,10 +31,10 @@ using namespace boost::program_options;
 #include <Poco/Net/NetException.h>
 #include <Poco/Net/POP3ClientSession.h>
 #include <Poco/Net/MailMessage.h>
-#include <Poco/Net/QuotedPrintableDecoder.h>
-
-using namespace Poco;
-using namespace Poco::Net;
+#include <Poco/Net/SecureStreamSocket.h>
+#include <Poco/Net/SSLManager.h>
+#include <Poco/Net/ConsoleCertificateHandler.h>
+#include <Poco/SharedPtr.h>
 
 //=== Pop3MailClient =======================================================
 Pop3MailClient::Pop3MailClient (const string& option_key)
@@ -42,18 +42,57 @@ Pop3MailClient::Pop3MailClient (const string& option_key)
 {
 }
 
-	static void decode_quoted_printable (string& s)
+	class SSLInitializer
 	{
-		stringstream ss(s);
-		QuotedPrintableDecoder decoder(ss);
-		string decoded;
-		decoder >> decoded;
-		s = decoded;
-	}
+		public:
 
-	static void convert_charset (string& s, const string& from_charset)
+		SSLInitializer()
+		{
+			Poco::Net::initializeSSL();
+		}
+
+		~SSLInitializer()
+		{
+			Poco::Net::uninitializeSSL();
+		}
+	};
+
+	static string extract_charset_from_content_type (const string& content_type)
 	{
-		s = Decode(s, SpecificEncoding(from_charset));
+		// a content type is normally something like this:
+		//
+		//	text/plain; charset=iso-8859-15
+		//
+		// the part in front of the semicolon defines the type of the
+		// content, we only accept text/plain here be definition, the
+		// other part defines the character set of the text
+		//
+		// some mail clients insert newlines after the semicolon or
+		// spaces or tabs at some places in this string, so we have to be
+		// very robust here
+
+		string s(content_type);
+		to_lower(s);
+
+		for (size_t i = 0; i < s.length(); i++)
+		{
+			if (s[i] < 0x20)
+				s[i] = 0x20;
+		}
+
+		static const regex rx_charset("^text/plain\\s*;\\s*charset\\s*=\\s*(.+)\\s*$");
+		smatch mr;
+		if (regex_match(s, mr, rx_charset, boost::match_not_dot_newline))
+		{
+			string charset(mr[1]);
+			string c(charset);
+			to_lower(c);
+			if (c == "us-ascii")
+				charset = "ASCII";
+			return charset;
+		}
+		else
+			return string(); // no charset or not text/plain
 	}
 
 void Pop3MailClient::Do (const Config& config, Database& database) const throw (Xception)
@@ -68,39 +107,68 @@ void Pop3MailClient::Do (const Config& config, Database& database) const throw (
 		const string& server = config.GetStringOption(m_option_key + ".server");
 		if (server.empty())
 			THROW(format("missing specification in configuration file: %s.server)") % m_option_key);
+
+		Poco::UInt16 port = (config.HasOption(m_option_key + ".port"))
+			? (Poco::UInt16)config.GetDoubleOption(m_option_key + ".port")
+			: 110;
+
 		const string& account = config.GetStringOption(m_option_key + ".account");
 		if (account.empty())
 			THROW(format("missing specification in configuration file: %s.account)") % m_option_key);
+
 		const string& password = config.GetStringOption(m_option_key + ".password");
 		const string& subject = config.GetStringOption(m_option_key + ".subject");
 		bool keep = config.GetBoolOption(m_option_key + ".keep");
 
-		// open connection and log in
-		POP3ClientSession session(server);
-		session.login(account, password);
+		// open connection
+		auto_ptr<SSLInitializer> pSSLInitializer;
+		auto_ptr<Poco::Net::SecureStreamSocket> pSSS;
+		auto_ptr<Poco::Net::POP3ClientSession> pSession;
+		if (port == 995)
+		{
+			// this magic stuff is from a Poco sample //////////
+			pSSLInitializer = auto_ptr<SSLInitializer>(new SSLInitializer());
+
+			Poco::SharedPtr<Poco::Net::InvalidCertificateHandler> pCert = new Poco::Net::ConsoleCertificateHandler(false);
+			Poco::Net::Context::Ptr pContext = new Poco::Net::Context(Poco::Net::Context::CLIENT_USE, "", "", "",
+				 Poco::Net::Context::VERIFY_RELAXED, 9, true, "ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH");
+			Poco::Net::SSLManager::instance().initializeClient(0, pCert, pContext);
+			////////////////////////////////////////////////////
+
+			// now we can open a secure socket ...
+			pSSS = auto_ptr<Poco::Net::SecureStreamSocket>(new Poco::Net::SecureStreamSocket(Poco::Net::SocketAddress(server, port)));
+
+			// ... and a session upon the socket as well
+			pSession = auto_ptr<Poco::Net::POP3ClientSession>(new Poco::Net::POP3ClientSession(*pSSS));
+		}
+		else
+			pSession = auto_ptr<Poco::Net::POP3ClientSession>(new Poco::Net::POP3ClientSession(server));
+
+		// we authenticate using a non-encrypted password
+		pSession->login(account, password);
 
 		// process available mails
-		POP3ClientSession::MessageInfoVec messages;
-		session.listMessages(messages);
+		Poco::Net::POP3ClientSession::MessageInfoVec messages;
+		pSession->listMessages(messages);
 
 		Database::Collections collections;
 		database.GetCollections(collections);
 
 		bool data = false;
 		bool rejects = false;
-		POP3ClientSession::MessageInfoVec::const_iterator I = messages.begin();
+		Poco::Net::POP3ClientSession::MessageInfoVec::const_iterator I = messages.begin();
 		while (I != messages.end())
 		{
 			int id = (*I++).id;
 
-			MailMessage message;
-			session.retrieveMessage(id, message);
+			Poco::Net::MailMessage message;
+			pSession->retrieveMessage(id, message);
 
 			// check subject
 			string s(message["Subject"]);
 			{
 				trim(s);
-				s = InputImpl::ConvertMailSubject(s, decode_quoted_printable, convert_charset);
+				s = InputImpl::ConvertMailSubject(s);
 			}
 
 			if (s != subject)
@@ -117,7 +185,7 @@ void Pop3MailClient::Do (const Config& config, Database& database) const throw (
 			}
 
 			// get message body and decode it correctly (this means make it UTF-8)
-			const string& charset = ExtractCharsetFromContentType(message.getContentType());
+			const string& charset = extract_charset_from_content_type(message.getContentType());
 			stringstream ss;
 			if (charset.empty())
 				ss << message.getContent(); // should be 7bit ASCII
@@ -148,16 +216,16 @@ void Pop3MailClient::Do (const Config& config, Database& database) const throw (
 
 			// delete if neccessary
 			if (!keep)
-				session.deleteMessage(id);
+				pSession->deleteMessage(id);
 		}
 		if (verbose && !data)
 			encoded::cout << "    no data on server" << endl;
 
 		// close connection
-		session.close();
+		pSession->close();
 
 		if (rejects)
 			encoded::cerr << "!!! at least one expression has been rejected, try -r to list rejections !!!" << endl;
 	}
-	CATCH_RETHROW("could not retrieve mail data from pop3 server")
+	CATCH_RETHROW("could not retrieve mail data from POP3 server")
 }
