@@ -248,8 +248,10 @@ void TwitterRssClient::Do (const Config& config, Database& database) const throw
 	const string& proxy = config.GetStringOption(m_option_key + ".proxy");
 
 	// open a HTTP connection
-	OAuthHttpClient http(consumer_key, consumer_secret, config, m_option_key);
-	http.Open("api.twitter.com", proxy);
+	OAuthHttpClient http("api.twitter.com", proxy, consumer_key, consumer_secret, config, m_option_key);
+	if (!http.Connected())
+		THROW("could not connect to Twitter");
+	http.Authenticate("");
 
 	// retrieve the last point in history we did request this feed,
 	// this should then be saved in the database, if we don't have
@@ -282,13 +284,12 @@ void TwitterRssClient::Do (const Config& config, Database& database) const throw
 			parser.addEncoding(name, &SpecificEncoding(name));
 		}
 
-		const string filename("http://api.twitter.com/1/statuses/user_timeline.rss");
+		const string filename("/1/statuses/user_timeline.rss");
 		size_t page = 1;
 		do
 		{
 			// do the HTTP request
-			http.Request("GET", filename + "?page=" + lexical_cast<string>(page++));
-			const string& response = http.Response();
+			const string& response = http.Request("GET", filename + "?page=" + lexical_cast<string>(page++));
 
 			// parse the output
 			try
@@ -313,9 +314,6 @@ void TwitterRssClient::Do (const Config& config, Database& database) const throw
 		} while (true);
 	}
 
-	// now we can truely close the HTTP connection
-	http.Close();
-
 	// put all the received stuff into the database
 	if (expressions.empty())
 	{
