@@ -47,12 +47,15 @@ OutputFactory::~OutputFactory ()
 	}
 }
 
-const OutputFactory::Outputs& OutputFactory::GetOutputs (const Config& config) throw (Xception)
+const OutputFactory::Outputs& OutputFactory::GetOutputs (const Config& config, bool has_action_options) throw (Xception)
 {
 	if (!m_initialized)
 	{
 		m_initialized = true;
 
+		// (until now we have no outputs that depend on
+		// has_action_options ...)
+
 		const string& filename = config.GetFilenameOption("export");
 		if (!filename.empty())
 			m_outputs.push_back(new OutputXML("", filename));
