@@ -23,6 +23,8 @@ using namespace boost::gregorian;
 using namespace boost::program_options;
 
 #include "../libpdrx/datatypes.h"
+#include "../libpdrx/xception.h"
+#include "../libpdrx/conversions.h"
 #include "../libpdrx/config.h"
 #include "db.h"
 #include "out_impl.h"
@@ -58,11 +60,11 @@ void OutputXML::Do (const Config& config, const Database& database) const throw
 {
 	bool verbose = config.GetBoolOption("verbose");
 	if (verbose)
-		cout << "exporting database as XML" << endl;
+		encoded::cout << "exporting database as XML" << endl;
 
 	ofstream ofs(m_filename.c_str(), ios::out);
 	if (!ofs.good())
-		throw Xception(format("error creating output file %s") % m_filename);
+		THROW(format("error creating output file %s") % m_filename);
 
 	ofs << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
 	ofs << "<pdr>" << endl;
