@@ -14,10 +14,10 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-#ifdef USE_SQLITE
-
 #include "../libpdrx/common.h"
 
+#ifdef USE_SQLITE
+
 #include <Poco/Data/Common.h>
 #include <Poco/Data/SQLite/Connector.h>
 #include <Poco/Data/SQLite/SQLiteException.h>
@@ -30,6 +30,7 @@ using namespace boost::program_options;
 using namespace Poco::Data;
 
 #include "../libpdrx/datatypes.h"
+#include "../libpdrx/xception.h"
 #include "config_impl.h"
 #include "db_impl.h"
 
@@ -47,10 +48,7 @@ string SQLiteDatabase::GetVersion () const throw (Xception)
 		(*m_pSession) << "select sqlite_version();", into(version), now;
 		return string("SQLite ") + version;
 	}
-	catch (...)
-	{
-		throw Xception("error determining database version");
-	}
+	CATCH_RETHROW("error determining database version")
 }
 
 #endif // USE_SQLITE
