@@ -82,7 +82,7 @@ Diagram* DiagramFactory::Create (const string& filename, bool antialias) throw (
 {
 	try
 	{
-		const string& ext = path(filename).extension();
+		const string ext(path(filename).extension().string());
 
 #ifdef USE_BOARD
 		if (ext == ".svg" || ext == ".SVG")
