@@ -27,6 +27,7 @@ using namespace boost::program_options;
 #include "../libpdrx/conversions.h"
 #include "config_impl.h"
 #include "diagram_impl.h"
+#include "spline.hpp"
 
 //=== DiagramImpl ==========================================================
 DiagramImpl::DiagramImpl ()
@@ -260,3 +261,34 @@ double DiagramImpl::GetFirstYAxisItem () const
 	}
 	CATCH_RETHROW("")
 }
+
+void DiagramImpl::Spline (XYs& xys, int splineValues) const
+{
+	if (xys.size() < 2)
+		return;
+
+	magnet::math::Spline spline;
+	foreach(const XY& xy, xys)
+	{
+		spline.addPoint(xy.first, xy.second);
+	}
+
+	XYs additional;
+	XYs::const_iterator I = xys.begin();
+	while (true)
+	{
+		const XY& b = *I++;
+		if (I == xys.end())
+			break;
+		const XY& e = *I;
+		for (double x = b.first; x <= e.first; x += (e.first - b.first) / splineValues)
+			additional.push_back(XY(x, spline(x)));
+	}
+
+	foreach(const XY& xy, additional)
+	{
+		xys.push_back(xy);
+	}
+
+	sort(xys.begin(), xys.end(), less_xy());
+}
