@@ -305,7 +305,7 @@ void BoardDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_ma
 	CATCH_RETHROW("")
 }
 
-void BoardDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, double thickness)
+void BoardDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, double thickness, size_t splineValues)
 {
 	try
 	{
@@ -336,38 +336,38 @@ void BoardDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 			size_t row = 0;
 			while (row < pDimensions[0])
 			{
-				vector<Point> points;
+				XYs xys;
 				for ( ; row < pDimensions[0]; row++)
 				{
 					Dot current(any_cast<string>(s[row][0]), s[row][1]);
-
 					if (current.m_timestamp < m_xmin)
 						continue;
-
 					if (!current)
 						break;
-
-					Point point(CalcX(current.m_timestamp), CalcY(any_cast<double>(current.m_value)));
-					size_t n = points.size();
+					XY xy(CalcX(current.m_timestamp), CalcY(any_cast<double>(current.m_value)));
+					size_t n = xys.size();
 					if (n > 1)
 					{
-						double y_2, y_1, y, x_dummy;
-						points[n - 2].get(x_dummy, y_2);
-						points[n - 1].get(x_dummy, y_1);
-						point.get(x_dummy, y);
+						double y_2 = xys[n - 2].second;
+						double y_1 = xys[n - 1].second;
+						double y = xy.second;
 						if (y_2 == y_1 && y_1 == y)
-							points.erase(--points.end());
+							xys.erase(--xys.end());
 					}
-					points.push_back(point);
+					xys.push_back(xy);
 				}
 
-				if (!points.empty())
+				if (!xys.empty())
 				{
+					if (splineValues > 1)
+						Spline(xys, splineValues);
+
 					LibBoard::Polyline polyline(false, COLOR(color), Color(false), (float)thickness);
-					foreach(const Point& point, points)
+					foreach(const XY& xy, xys)
 					{
-						polyline << point;
+						polyline << Point(xy.first, xy.second);
 					}
+
 					m_shapes << polyline;
 				}
 			}
