@@ -403,7 +403,7 @@ void CairoDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_ma
 	CATCH_RETHROW("")
 }
 
-void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, double thickness)
+void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, double thickness, size_t splineValues)
 {
 	try
 	{
@@ -417,34 +417,60 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 
 		cairo_set_source_rgb(m_pContext, RED(color), GREEN(color), BLUE(color));
 
-		Dot last;
-		for (size_t row = 0; row < pDimensions[0]; row++)
+		if (style == zigzag)
 		{
-			Dot current(any_cast<string>(s[row][0]), s[row][1]);
-
-			switch (style)
+			XYs xys;
+			for (size_t row = 0; row < pDimensions[0]; row++)
 			{
-				case symbol_dot:
+				Dot current(any_cast<string>(s[row][0]), s[row][1]);
+				if (!current)
+					continue;
+				if (current.m_timestamp < m_xmin)
+					continue;
+				xys.push_back(XY(CalcX(current.m_timestamp), CalcY(any_cast<double>(current.m_value))));
+			}
+
+ 			if (!xys.empty())
+			{
+				if (splineValues > 1)
+					Spline(xys, splineValues);
+
+				cairo_set_line_width(m_pContext, thickness);
+				XYs::const_iterator I = xys.begin();
+				const XY& xy1 = *I;
+				move_to(xy1.first, xy1.second);
+				while (I != xys.end())
 				{
-					if (current)
+					const XY& xy2 = *I++;
+					line_to(xy2.first, xy2.second);
+				}
+				cairo_stroke(m_pContext);
+			}
+		}
+		else
+		{
+			for (size_t row = 0; row < pDimensions[0]; row++)
+			{
+				Dot current(any_cast<string>(s[row][0]), s[row][1]);
+				if (!current)
+					continue;
+				if (current.m_timestamp < m_xmin)
+					continue;
+
+				switch (style)
+				{
+					case symbol_dot:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
 						move_to(x - thickness / 2.0, y);
 						line_to(x + thickness / 2.0, y);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				case symbol_plus:
-				{
-					if (current)
+					case symbol_plus:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
@@ -454,15 +480,10 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 						move_to(x, y - extent);
 						line_to(x, y + extent);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				case symbol_vbar:
-				{
-					if (current)
+					case symbol_vbar:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
@@ -470,15 +491,10 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 						move_to(x, y - extent);
 						line_to(x, y + extent);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				case symbol_hbar:
-				{
-					if (current)
+					case symbol_hbar:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
@@ -486,15 +502,10 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 						move_to(x - extent, y);
 						line_to(x + extent, y);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				case symbol_x:
-				{
-					if (current)
+					case symbol_x:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
@@ -504,15 +515,10 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 						move_to(x - extent, y + extent);
 						line_to(x + extent, y - extent);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				case symbol_X:
-				{
-					if (current)
+					case symbol_X:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
@@ -522,15 +528,10 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 						move_to(x - extent, y + extent);
 						line_to(x + extent, y - extent);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				case symbol_circle:
-				{
-					if (current)
+					case symbol_circle:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
@@ -538,15 +539,10 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 						cairo_arc(m_pContext, x, y, extent / 2.0, 0.0, 2.0 * M_PI);
 						UpdateOrigin(x - extent / 2.0, y + extent / 2.0);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				case symbol_square:
-				{
-					if (current)
+					case symbol_square:
 					{
-						if (current.m_timestamp < m_xmin)
-							continue;
 						cairo_set_line_width(m_pContext, thickness);
 						double x = CalcX(current.m_timestamp);
 						double y = CalcY(any_cast<double>(current.m_value));
@@ -554,25 +550,12 @@ void CairoDiagram::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 						cairo_rectangle(m_pContext, x - extent / 2.0, y - extent / 2.0, extent, extent);
 						UpdateOrigin(x - extent / 2.0, y + extent / 2.0);
 						cairo_stroke(m_pContext);
+						break;
 					}
-					break;
-				}
-				default: // zick-zack
-				{
-					if (current.m_timestamp < m_xmin)
-						continue;
-					if (last && current)
-					{
-						cairo_set_line_width(m_pContext, thickness);
-						move_to(CalcX(last.m_timestamp), CalcY(any_cast<double>(last.m_value)));
-						line_to(CalcX(current.m_timestamp), CalcY(any_cast<double>(current.m_value)));
-						cairo_stroke(m_pContext);
-					}
-					break;
+					default:
+						break;
 				}
 			}
-
-			last = current;
 		}
 	}
 	CATCH_RETHROW("")
