@@ -35,28 +35,6 @@ ConfigImpl::ConfigImpl ()
 	: Config()
 	, m_periods()
 {
-	m_od_visible.add_options()
-
-		// common options
-		("help,?",			"show this help screen and quit")
-		("version,V",			"display version number and quit")
-		("verbose,v",			"produce verbose output on stdout")
-		("config,c", value<string>(),	"use specific configuration file")
-		("midnight,m", value<string>(),	"define what is midnight, arg is hh:mm[:ss]")
-		("now,n", value<string>(),	"define what is \"now\", arg is CCYY-MM-DD[-hh:mm[:ss]]")
-		("interactive,i",		"don't generate any output, start interactive")
-		("fast,f",			"cache internal informations in memory, needs much more RAM")
-		("debug",			"dump call stack in case of exceptions")
-	;
-
-	// further we need named options for the list of the configured
-	// outputs and for the sum of all the given command line outputs,
-	// but we don't want to have this on the help screen
-	m_od_cmdline.add_options() ("outputs", value<string>(), "");
-	m_od_cmdline.add_options() ("cmd_line_outputs", value<string>(), "");
-
-	m_od_cmdline.add_options() ("cmd_line_args", value<vector<string> >(), "");
-	m_pod.add("cmd_line_args", -1); // unlimited
 }
 
 ConfigImpl::~ConfigImpl ()
@@ -67,6 +45,51 @@ ConfigImpl::~ConfigImpl ()
 	}
 }
 
+void ConfigImpl::HandleApplicationName ()
+{
+	if (m_app_name == "pdxi")
+	{
+		m_od_visible.add_options()
+
+			// common options
+			("help,?",			"show this help screen and quit")
+			("version,V",			"display version number and quit")
+			("config,c", value<string>(),	"use specific configuration file")
+			("midnight,m", value<string>(),	"define what is midnight, arg is hh:mm[:ss]")
+			("now,n", value<string>(),	"define what is \"now\", arg is CCYY-MM-DD[-hh:mm[:ss]]")
+			("fast,f",			"cache internal informations in memory, needs much more RAM")
+			("debug",			"dump call stack in case of exceptions")
+		;
+
+		m_od_cmdline.add_options() ("interactive", "");
+	}
+	else
+	{
+		m_od_visible.add_options()
+
+			// common options
+			("help,?",			"show this help screen and quit")
+			("version,V",			"display version number and quit")
+			("verbose,v",			"produce verbose output on stdout")
+			("config,c", value<string>(),	"use specific configuration file")
+			("midnight,m", value<string>(),	"define what is midnight, arg is hh:mm[:ss]")
+			("now,n", value<string>(),	"define what is \"now\", arg is CCYY-MM-DD[-hh:mm[:ss]]")
+			("interactive,i",		"don't generate any output, start interactive")
+			("fast,f",			"cache internal informations in memory, needs much more RAM")
+			("debug",			"dump call stack in case of exceptions")
+		;
+
+		// further we need named options for the list of the configured
+		// outputs and for the sum of all the given command line outputs,
+		// but we don't want to have this on the help screen
+		m_od_cmdline.add_options() ("outputs", value<string>(), "");
+		m_od_cmdline.add_options() ("cmd_line_outputs", value<string>(), "");
+
+		m_od_cmdline.add_options() ("cmd_line_args", value<vector<string> >(), "");
+		m_pod.add("cmd_line_args", -1); // unlimited
+	}
+}
+
 	struct fo_cmd_line_arg: public unary_function<option&, bool> {
 		string& m_cmd_line_outputs;
 		fo_cmd_line_arg (string& cmd_line_outputs)
@@ -112,6 +135,11 @@ void ConfigImpl::ModifyCmdLineOptions (parsed_options& po)
 			values.push_back(cmd_line_outputs);
 			po.options.push_back(option("cmd_line_outputs", values));
 		}
+
+		// check if we are called interactively, then we fake a
+		// -i parameter
+		if (m_app_name == "pdxi")
+			po.options.push_back(option("interactive", vector<string>()));
 	}
 	CATCH_RETHROW("")
 }
@@ -191,9 +219,18 @@ int main (int argc, char* argv[])
 		// handle the very simple cases
 		if (config->GetBoolOption("version"))
 		{
+			if (config->GetApplicationName() == "pdxi")
+			{
+				encoded::cout
+					<< "pdxi - personal data expert (interactive), " << VERSION << endl;
+			}
+			else
+			{
+				encoded::cout
+					<< "pdx - personal data expert, " << VERSION << endl;
+			}
 			encoded::cout
-				<< "pdx - personal data expert, " << VERSION << endl
-				<< "(C) 2010-2011 Torsten Mueller, Bern, Switzerland" << endl
+				<< "(C) 2010-2012 Torsten Mueller, Bern, Switzerland" << endl
 				<< '(' << BUILD << ')' << endl
 				<< "This program is free software under the terms of the GNU General Public License v2 or later." << endl;
 			return 0;
@@ -201,9 +238,18 @@ int main (int argc, char* argv[])
 
 		if (config->GetBoolOption("help"))
 		{
-			encoded::cout
-				<< "pdx - personal data expert" << endl
-				<< "usage: pdx [options] [outputs]" << endl;
+			if (config->GetApplicationName() == "pdxi")
+			{
+				encoded::cout
+					<< "pdxi - personal data expert (interactive)" << endl
+					<< "usage: pdx [options]" << endl;
+			}
+			else
+			{
+				encoded::cout
+					<< "pdx - personal data expert" << endl
+					<< "usage: pdx [options] [outputs]" << endl;
+			}
 			config->Help(encoded::cout);
 			return 0;
 		}
